@@ -127,6 +127,17 @@ def addLogo(doc):
     html = doc.fixText(html)
     fillWith('logo', parseHTML(html), doc=doc)
 
+def addSubstatus(doc):
+    container = getFillContainer("substatus", doc, default=False)
+    if container is None:
+        return
+    if doc.md.status == "w3c/CR":
+        appendChild(container, E.span("Snapshot"))
+    elif doc.md.status == "w3c/CRD":
+        appendChild(container, E.span("Draft"))
+    else:
+        if container is not None:
+            removeNode(container)
 
 def addCopyright(doc):
     html = config.retrieveBoilerplateFile(doc, 'copyright')
@@ -226,6 +237,21 @@ def addBikeshedBoilerplate(doc):
     for k,v in sorted(doc.extraStyles.items()):
         if k not in doc.md.boilerplate:
             continue
+        if k == "style-darkmode":
+            # Have to output these *last* so they'll override preceding colors.
+            continue
+        container = getFillContainer(k, doc)
+        if container is None:
+            container = getFillContainer("bs-styles", doc, default=True)
+        if container is not None:
+            appendChild(container,
+                        E.style("/* {0} */\n".format(k) + v))
+    # Output the darkmode styles after all other styles
+    # but don't put them in /TR space yet,
+    # until the W3C is ready for them.
+    if "style-darkmode" in doc.md.boilerplate and not doc.md.prepTR:
+        k = "style-darkmode"
+        v = doc.extraStyles[k]
         container = getFillContainer(k, doc)
         if container is None:
             container = getFillContainer("bs-styles", doc, default=True)
@@ -458,7 +484,7 @@ def addIndexOfExternallyDefinedTerms(doc, container):
         return
 
     def makeLink(*contents):
-        return E.span({"style":"color:initial"}, *contents)
+        return E.span({}, *contents)
 
     ul = E.ul({"class": "index"})
     # Gather all the <a href> in the document, for use in the dfn-panels
@@ -470,6 +496,7 @@ def addIndexOfExternallyDefinedTerms(doc, container):
         if href.startswith("#"):
             continue
         elsFromHref[href].append(a)
+    atLeastOnePanel = False
     for spec, refGroups in sorted(doc.externalRefsUsed.items(), key=lambda x:x[0].upper()):
         # ref.spec is always lowercase; if the same string shows up in biblio data,
         # use its casing instead.
@@ -494,7 +521,10 @@ def addIndexOfExternallyDefinedTerms(doc, container):
                     else:
                         link = makeLink(ref.text)
             appendChild(termsUl, E.li(link))
+            atLeastOnePanel = True
             dfnpanels.addExternalDfnPanel(link, ref, elsFromHref, doc)
+    if atLeastOnePanel:
+        dfnpanels.addExternalDfnPanelStyles(doc)
     appendChild(container,
                 E.h3({"class":"no-num no-ref", "id":safeID(doc, "index-defined-elsewhere")}, "Terms defined by reference"),
                 ul)
@@ -827,6 +857,8 @@ def addSpecMetadataSection(doc):
                         E.a({"rel":"discussion", "href":doc.md.mailingListArchives}, "archives"),
                         ")")
         md["Feedback"].append(span)
+    if doc.md.implementationReport is not None:
+        md["Implementation Report"].append(E.a({"href":doc.md.implementationReport}, doc.md.implementationReport))
     if doc.md.testSuite is not None:
         md["Test Suite"].append(E.a({"href":doc.md.testSuite}, doc.md.testSuite))
     elif (doc.md.vshortname in doc.testSuites) and (doc.testSuites[doc.md.vshortname]['url'] is not None):
@@ -835,11 +867,9 @@ def addSpecMetadataSection(doc):
     if doc.md.issues:
         md["Issue Tracking"] = [E.a({"href":href}, text) for text,href in doc.md.issues]
     if doc.md.editors:
-        editorTerm = doc.md.editorTerm['singular']
-        md[editorTerm] = list(map(printEditor, doc.md.editors))
+        md["Editor"] = list(map(printEditor, doc.md.editors))
     if doc.md.previousEditors:
-        editorTerm = doc.md.editorTerm['singular']
-        md["Former " + editorTerm] = list(map(printEditor, doc.md.previousEditors))
+        md["Former Editor"] = list(map(printEditor, doc.md.previousEditors))
     if doc.md.translations:
         md["Translations"] = list(map(printTranslation, doc.md.translations))
     if doc.md.audience:
@@ -860,6 +890,13 @@ def addSpecMetadataSection(doc):
         vals = list(filter(lambda x:x is not None, vals))
         if not vals:
             return []
+        # Convert the canonical key to a display version
+        if key == "Editor":
+            displayKey = doc.md.editorTerm['singular']
+        elif key == "Former Editor":
+            displayKey = "Former " + doc.md.editorTerm['singular']
+        else:
+            displayKey = key
         # Pluralize appropriate words
         pluralization = {
             "Previous Version": "Previous Versions",
@@ -867,20 +904,22 @@ def addSpecMetadataSection(doc):
             doc.md.editorTerm['singular']: doc.md.editorTerm['plural'],
             "Former " + doc.md.editorTerm['singular']: "Former " + doc.md.editorTerm['plural']
         }
-        if len(vals) > 1 and key in pluralization:
-            displayKey = pluralization[key]
-        else:
-            displayKey = key
+        if len(vals) > 1 and displayKey in pluralization:
+            displayKey = pluralization[displayKey]
+        # Handle some custom <dt> structures
         if key in ("Editor", "Former Editor"):
-            # A bunch of Microformats stuff is preloaded on the <dd>s,
-            # so this prevents code from genning an extra wrapper <dd>.
-            return [E.dt({"class": "editor"}, displayKey, ":")] + vals
+            ret = [E.dt({"class": "editor"}, displayKey, ":")]
         elif key == "Translations":
             ret = [E.dt(displayKey, " ", E.small("(non-normative)"), ":")]
-            ret += [E.dd({}, val) for val in vals]
-            return ret
         else:
-            return [E.dt(displayKey, ":")] + [E.dd({}, val) for val in vals]
+            ret = [E.dt(displayKey, ":")]
+        # Add all the values, wrapping in a <dd> if necessary.
+        for val in vals:
+            if isElement(val) and val.tag == "dd":
+                ret.append(val)
+            else:
+                ret.append(E.dd({}, val))
+        return ret
 
     # Merge "custom" metadata into non-custom, when they match up
     otherMd = OrderedDict()
