@@ -19,6 +19,7 @@ shortToLongStatus = {
     "w3c/FPWD": "W3C First Public Working Draft",
     "w3c/LCWD": "W3C Last Call Working Draft",
     "w3c/CR": "W3C Candidate Recommendation",
+    "w3c/CRD": "W3C Candidate Recommendation",
     "w3c/PR": "W3C Proposed Recommendation",
     "w3c/REC": "W3C Recommendation",
     "w3c/PER": "W3C Proposed Edited Recommendation",
@@ -80,8 +81,9 @@ shortToLongStatus = {
     "fido/FD": "Final Document",
     "khronos/ED": "Editor's Draft"
 }
-snapshotStatuses = ["w3c/WD", "w3c/FPWD", "w3c/LCWD", "w3c/CR", "w3c/PR", "w3c/REC", "w3c/PER", "w3c/WG-NOTE", "w3c/IG-NOTE", "w3c/NOTE", "w3c/MO"]
-datedStatuses = ["w3c/WD", "w3c/FPWD", "w3c/LCWD", "w3c/CR", "w3c/PR", "w3c/REC", "w3c/PER", "w3c/WG-NOTE", "w3c/IG-NOTE", "w3c/NOTE", "w3c/MO", "whatwg/RD"]
+snapshotStatuses = ["w3c/WD", "w3c/FPWD", "w3c/LCWD", "w3c/CR", "w3c/CRD", "w3c/PR", "w3c/REC", "w3c/PER", "w3c/WG-NOTE", "w3c/IG-NOTE", "w3c/NOTE", "w3c/MO"]
+datedStatuses = ["w3c/WD", "w3c/FPWD", "w3c/LCWD", "w3c/CR", "w3c/CRD", "w3c/PR", "w3c/REC", "w3c/PER", "w3c/WG-NOTE", "w3c/IG-NOTE", "w3c/NOTE", "w3c/MO", "whatwg/RD"]
+implementationStatuses = ["w3c/CR", "w3c/CRD", "w3c/PR", "w3c/REC"]
 unlevelledStatuses = ["LS", "LD", "DREAM", "w3c/UD", "LS-COMMIT", "LS-BRANCH", "LS-PR", "FINDING", "DRAFT-FINDING", "whatwg/RD"]
 deadlineStatuses = ["w3c/LCWD", "w3c/PR"]
 noEDStatuses = ["LS", "LS-COMMIT", "LS-BRANCH", "LS-PR", "LD", "FINDING", "DRAFT-FINDING", "DREAM", "iso/NP", "whatwg/RD"]
@@ -106,6 +108,7 @@ w3cWGStatuses = frozenset([
     "w3c/FPWD",
     "w3c/LCWD",
     "w3c/CR",
+    "w3c/CRD",
     "w3c/PR",
     "w3c/REC",
     "w3c/PER",
@@ -124,7 +127,7 @@ w3cCommunityStatuses = frozenset([
 ])
 
 megaGroups = {
-    "w3c": frozenset(["act-framework", "audiowg", "browser-testing-tools", "csswg", "dap", "fxtf", "fxtf-csswg", "geolocation", "houdini", "html", "i18n", "immersivewebcg", "immersivewebwg", "mediacapture", "mediawg", "ping", "privacycg", "processcg", "ricg", "sacg", "secondscreenwg", "serviceworkers", "svg", "tag", "texttracks", "uievents", "wasm", "web-bluetooth-cg", "webapps", "webappsec", "webauthn", "webml", "web-payments", "webperf", "webplatform", "webrtc", "webspecs", "webvr", "wicg"]),
+    "w3c": frozenset(["act-framework", "audiowg", "browser-testing-tools", "csswg", "dap", "fxtf", "fxtf-csswg", "geolocation", "houdini", "html", "i18n", "immersivewebcg", "immersivewebwg", "mediacapture", "mediawg", "ping", "privacycg", "processcg", "ricg", "sacg", "secondscreencg", "secondscreenwg", "serviceworkers", "svg", "tag", "texttracks", "uievents", "wasm", "web-bluetooth-cg", "webapps", "webappsec", "webauthn", "webml", "web-payments", "webperf", "webplatform", "webrtc", "webspecs", "webvr", "wicg"]),
     "whatwg": frozenset(["whatwg"]),
     "tc39": frozenset(["tc39"]),
     "iso": frozenset(["wg14", "wg21"]),
@@ -263,3 +266,21 @@ def canonicalizeStatus(rawStatus, group):
         msg = "Unknown Status metadata '{0}'. Check the docs for valid Status values.".format(canonStatus)
     die("{0}", msg)
     return canonStatus
+
+def splitStatus(st):
+    parts = st.partition("/")
+    if parts[2] == "":
+        return None, parts[0]
+    return parts[0], parts[2]
+
+def looselyMatch(s1, s2):
+    # Loosely matches two statuses:
+    # they must have the same status name,
+    # and either the same or missing group name
+    group1, status1 = splitStatus(s1)
+    group2, status2 = splitStatus(s2)
+    if status1 != status2:
+        return False
+    if group1 == group2 or group1 is None or group2 is None:
+        return True
+    return False
\ No newline at end of file
