@@ -46,10 +46,13 @@ def addSyntaxHighlighting(doc):
 
     if highlightingOccurred:
         doc.extraStyles['style-syntax-highlighting'] += getHighlightStyles()
+        doc.extraStyles['style-darkmode'] += getHighlightDarkmodeStyles()
     if lineWrappingOccurred:
         doc.extraStyles['style-line-numbers'] += getLineNumberStyles()
+        doc.extraStyles['style-darkmode'] += getLineNumberDarkmodeStyles()
     if lineHighlightingOccurred:
         doc.extraStyles['style-line-highlighting'] += getLineHighlightingStyles()
+        doc.extraStyles['style-darkmode'] += getLineHighlightingDarkmodeStyles()
 
 
 def determineHighlightLang(doc, el):
@@ -462,9 +465,10 @@ def getHighlightStyles():
     #    }
     #print formatters.HtmlFormatter(style=PrismStyle).get_style_defs('.highlight')
     return '''
-.highlight:not(.idl) { background: hsl(24, 20%, 95%); }
 code.highlight { padding: .1em; border-radius: .3em; }
 pre.highlight, pre > code.highlight { display: block; padding: 1em; margin: .5em 0; overflow: auto; border-radius: 0; }
+
+.highlight:not(.idl) { background: #fdf6e3; }
 c-[a] { color: #990055 } /* Keyword.Declaration */
 c-[b] { color: #990055 } /* Keyword.Type */
 c-[c] { color: #708090 } /* Comment */
@@ -518,9 +522,77 @@ c-[vg] { color: #0077aa } /* Name.Variable.Global */
 c-[vi] { color: #0077aa } /* Name.Variable.Instance */
 c-[il] { color: #000000 } /* Literal.Number.Integer.Long */
 '''
+def getHighlightDarkmodeStyles():
+    return '''
+@media (prefers-color-scheme: dark) {
+    .highlight:not(.idl) { background: rgba(255, 255, 255, .05); }
+
+    c-[a] { color: #d33682 } /* Keyword.Declaration */
+    c-[b] { color: #d33682 } /* Keyword.Type */
+    c-[c] { color: #2aa198 } /* Comment */
+    c-[d] { color: #2aa198 } /* Comment.Multiline */
+    c-[e] { color: #268bd2 } /* Name.Attribute */
+    c-[f] { color: #b58900 } /* Name.Tag */
+    c-[g] { color: #cb4b16 } /* Name.Variable */
+    c-[k] { color: #d33682 } /* Keyword */
+    c-[l] { color: #657b83 } /* Literal */
+    c-[m] { color: #657b83 } /* Literal.Number */
+    c-[n] { color: #268bd2 } /* Name */
+    c-[o] { color: #657b83 } /* Operator */
+    c-[p] { color: #657b83 } /* Punctuation */
+    c-[s] { color: #6c71c4 } /* Literal.String */
+    c-[t] { color: #6c71c4 } /* Literal.String.Single */
+    c-[u] { color: #6c71c4 } /* Literal.String.Double */
+    c-[ch] { color: #2aa198 } /* Comment.Hashbang */
+    c-[cp] { color: #2aa198 } /* Comment.Preproc */
+    c-[cpf] { color: #2aa198 } /* Comment.PreprocFile */
+    c-[c1] { color: #2aa198 } /* Comment.Single */
+    c-[cs] { color: #2aa198 } /* Comment.Special */
+    c-[kc] { color: #d33682 } /* Keyword.Constant */
+    c-[kn] { color: #d33682 } /* Keyword.Namespace */
+    c-[kp] { color: #d33682 } /* Keyword.Pseudo */
+    c-[kr] { color: #d33682 } /* Keyword.Reserved */
+    c-[ld] { color: #657b83 } /* Literal.Date */
+    c-[nc] { color: #268bd2 } /* Name.Class */
+    c-[no] { color: #268bd2 } /* Name.Constant */
+    c-[nd] { color: #268bd2 } /* Name.Decorator */
+    c-[ni] { color: #268bd2 } /* Name.Entity */
+    c-[ne] { color: #268bd2 } /* Name.Exception */
+    c-[nf] { color: #268bd2 } /* Name.Function */
+    c-[nl] { color: #268bd2 } /* Name.Label */
+    c-[nn] { color: #268bd2 } /* Name.Namespace */
+    c-[py] { color: #268bd2 } /* Name.Property */
+    c-[ow] { color: #657b83 } /* Operator.Word */
+    c-[mb] { color: #657b83 } /* Literal.Number.Bin */
+    c-[mf] { color: #657b83 } /* Literal.Number.Float */
+    c-[mh] { color: #657b83 } /* Literal.Number.Hex */
+    c-[mi] { color: #657b83 } /* Literal.Number.Integer */
+    c-[mo] { color: #657b83 } /* Literal.Number.Oct */
+    c-[sa] { color: #6c71c4 } /* Literal.String.Affix */
+    c-[sb] { color: #6c71c4 } /* Literal.String.Backtick */
+    c-[sc] { color: #6c71c4 } /* Literal.String.Char */
+    c-[dl] { color: #6c71c4 } /* Literal.String.Delimiter */
+    c-[sd] { color: #6c71c4 } /* Literal.String.Doc */
+    c-[se] { color: #6c71c4 } /* Literal.String.Escape */
+    c-[sh] { color: #6c71c4 } /* Literal.String.Heredoc */
+    c-[si] { color: #6c71c4 } /* Literal.String.Interpol */
+    c-[sx] { color: #6c71c4 } /* Literal.String.Other */
+    c-[sr] { color: #6c71c4 } /* Literal.String.Regex */
+    c-[ss] { color: #6c71c4 } /* Literal.String.Symbol */
+    c-[fm] { color: #268bd2 } /* Name.Function.Magic */
+    c-[vc] { color: #cb4b16 } /* Name.Variable.Class */
+    c-[vg] { color: #cb4b16 } /* Name.Variable.Global */
+    c-[vi] { color: #cb4b16 } /* Name.Variable.Instance */
+    c-[vm] { color: #cb4b16 } /* Name.Variable.Magic */
+    c-[il] { color: #657b83 } /* Literal.Number.Integer.Long */
+}
+'''
 
 def getLineNumberStyles():
     return '''
+:root {
+    --highlight-hover-bg: rgba(0, 0, 0, .05);
+}
 .line-numbered {
     display: grid !important;
     grid-template-columns: min-content 1fr;
@@ -539,7 +611,7 @@ def getLineNumberStyles():
     grid-column: 2;
 }
 .line:hover {
-    background: rgba(0,0,0,.05);
+    background: var(--highlight-hover-bg);
 }
 .line-no[data-line]::before {
     padding: 0 .5em 0 .1em;
@@ -551,8 +623,20 @@ def getLineNumberStyles():
 }
 '''
 
+def getLineNumberDarkmodeStyles():
+    return '''
+@media (prefers-color-scheme: dark) {
+    :root {
+        --highlight-hover-bg: rgba(255, 255, 255, .05);
+    }
+}
+'''
+
 def getLineHighlightingStyles():
     return '''
+:root {
+    --highlight-hover-bg: rgba(0, 0, 0, .05);
+}
 .line-numbered {
     display: grid !important;
     grid-template-columns: min-content 1fr;
@@ -571,10 +655,10 @@ def getLineHighlightingStyles():
     grid-column: 2;
 }
 .line.highlight-line {
-    background: rgba(0,0,0,.05);
+    background: var(--highlight-hover-bg);
 }
 .line-no.highlight-line {
-    background: rgba(0,0,0,.05);
+    background: var(--highlight-hover-bg);
     color: #444;
     font-weight: bold;
 }
@@ -588,6 +672,15 @@ def getLineHighlightingStyles():
 }
 '''
 
+def getLineHighlightingDarkmodeStyles():
+    return '''
+@media (prefers-color-scheme: dark) {
+    :root {
+        --highlight-hover-bg: rgba(255, 255, 255, .05);
+    }
+}
+'''
+
 
 def grouper(iterable, n, fillvalue=None):
     "Collect data into fixed-length chunks or blocks"
