@@ -65,6 +65,7 @@ class MetadataManager:
         self.date = datetime.utcnow().date()
         self.deadline = None
         self.defaultHighlight = None
+        self.defaultBiblioDisplay = "index"
         self.defaultRefStatus = None
         self.displayShortname = None
         self.editors = []
@@ -78,6 +79,7 @@ class MetadataManager:
         self.ignoreCanIUseUrlFailure = []
         self.ignoredTerms = []
         self.ignoredVars = []
+        self.implementationReport = None
         self.includeCanIUsePanels = False
         self.includeMdnPanels = False
         self.indent = 4
@@ -188,6 +190,14 @@ class MetadataManager:
         if self.displayShortname:
             self.shortname = self.displayShortname.lower()
 
+        # Temporary fix until W3C publishes a better version of the image
+        if self.status in ["w3c/CG-DRAFT", "w3c/UD"] and not self.prepTR:
+            doc.extraStyles['darkmode'] += '''
+            @media (prefers-color-scheme: dark) {
+                html { background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='400' height='400'%3E%3Cg fill='%23100808' transform='translate(200 200) rotate(-45) translate(-200 -200)' stroke='%23100808' stroke-width='3'%3E%3Ctext x='50%25' y='220' style='font: bold 70px sans-serif; text-anchor: middle; letter-spacing: 6px;'%3EUNOFFICIAL%3C/text%3E%3Ctext x='50%25' y='305' style='font: bold 70px sans-serif; text-anchor: middle; letter-spacing: 6px;'%3EDRAFT%3C/text%3E%3C/g%3E%3C/svg%3E") !important; }
+            }
+            '''
+
     def validate(self):
         if self.group == "byos":
             return True
@@ -213,6 +223,9 @@ class MetadataManager:
             recommendedSingularKeys['date'] = 'Date'
         if self.status in config.snapshotStatuses:
             requiredSingularKeys['TR'] = "TR"
+            requiredMultiKeys['issues'] = "Issue Tracking"
+        if self.status in config.implementationStatuses:
+            requiredSingularKeys['implementationReport'] = "Implementation Report"
         if self.status not in config.unlevelledStatuses:
             requiredSingularKeys['level'] = 'Level'
         if self.status not in config.shortToLongStatus:
@@ -562,6 +575,15 @@ def parseBoilerplate(key, val, lineNum):
     return boilerplate
 
 
+def parseBiblioDisplay(key, val, lineNum):
+    val = val.strip().lower()
+    if val in constants.biblioDisplay:
+        return val
+    else:
+        die("'{0}' must be either 'inline' or 'index'. Got '{1}'", key, val, lineNum=lineNum)
+        return constants.biblioDisplay.index
+
+
 def parseRefStatus(key, val, lineNum):
     val = val.strip().lower()
     if val == "dated":
@@ -757,7 +779,7 @@ def parseAudience(key, val, lineNum):
     elif len(values) >= 1:
         ret = []
         namedAudiences = {"CWG", "LWG", "EWG", "LEWG", "DIRECTION"}
-        pseudonymAudiences = {"Concurrency":"SG1", "TM":"SG5", "Numerics":"SG6", "Reflection":"SG7", "UB":"SG12", "HMI":"SG13", "Tooling":"SG15", "Unicode":"SG16", "EWGI":"SG17", "LEWG":"SG18"}
+        pseudonymAudiences = {"Concurrency":"SG1", "Modules":"SG2", "Networking":"SG4", "TM":"SG5", "Numerics":"SG6", "Reflection":"SG7", "FeatureTesting":"SG10", "UB":"SG12", "HMI":"SG13", "LowLatency":"SG14", "Tooling":"SG15", "Unicode":"SG16", "EWGI":"SG17", "LEWGI":"SG18", "MachineLearning":"SG19", "Education":"SG20", "Contracts":"SG21"}
         for v in values:
             if v in namedAudiences:
                 ret.append(v)
@@ -1042,6 +1064,7 @@ knownKeys = {
     "Custom Warning Title": Metadata("Custom Warning Title", "customWarningTitle", joinValue, parseLiteral),
     "Date": Metadata("Date", "date", joinValue, parseDate),
     "Deadline": Metadata("Deadline", "deadline", joinValue, parseDate),
+    "Default Biblio Display": Metadata("Default Biblio Display", "defaultBiblioDisplay", joinValue, parseBiblioDisplay),
     "Default Biblio Status": Metadata("Default Biblio Status", "defaultRefStatus", joinValue, parseRefStatus), #synonym of "Default Ref Status"
     "Default Highlight": Metadata("Default Highlight", "defaultHighlight", joinValue, parseLiteral),
     "Default Ref Status": Metadata("Default Ref Status", "defaultRefStatus", joinValue, parseRefStatus),
@@ -1058,6 +1081,7 @@ knownKeys = {
     "Ignore Can I Use Url Failure": Metadata("Ignore Can I Use Url Failure", "ignoreCanIUseUrlFailure", joinList, parseLiteralList),
     "Ignored Terms": Metadata("Ignored Terms", "ignoredTerms", joinList, parseCommaSeparated),
     "Ignored Vars": Metadata("Ignored Vars", "ignoredVars", joinList, parseCommaSeparated),
+    "Implementation Report": Metadata("Implementation Report", "implementationReport", joinValue, parseLiteral),
     "Include Can I Use Panels": Metadata("Include Can I Use Panels", "includeCanIUsePanels", joinValue, parseBoolean),
     "Include Mdn Panels": Metadata("Include Mdn Panels", "includeMdnPanels", joinValue, parseSoftBoolean),
     "Indent": Metadata("Indent", "indent", joinValue, parseInteger),
